@@ -24,10 +24,12 @@
 #ifndef _HTMLOBJECT_H_
 #define _HTMLOBJECT_H_
 
-#include <gtk/gtk.h>
+#include <libart_lgpl/art_rect.h>
+#include <gdk/gdktypes.h>
 #include "htmltypes.h"
 #include "htmlenums.h"
 
+
 #define HTML_OBJECT(x)		((HTMLObject *) (x))
 #define HTML_OBJECT_CLASS(x)	((HTMLObjectClass *) (x))
 #define HTML_OBJECT_TYPE(x)     (HTML_OBJECT (x)->klass->type)
@@ -71,7 +73,7 @@ struct _HTMLObject {
 	GData *object_data;
 	GData *object_data_nocp;
 
-	gchar *id;
+	char *id;
 };
 
 struct _HTMLObjectClearRectangle {
@@ -267,8 +269,8 @@ struct _HTMLObjectClass {
 	gboolean (*cursor_right)         (HTMLObject *self, HTMLPainter *painter, HTMLCursor *cursor);
 	gboolean (*cursor_left)          (HTMLObject *self, HTMLPainter *painter, HTMLCursor *cursor);
 
-	gint (*get_right_edge_offset) (HTMLObject *o, HTMLPainter *painter, gint offset);
-	gint (*get_left_edge_offset) (HTMLObject *o, HTMLPainter *painter, gint offset);
+	int (*get_right_edge_offset) (HTMLObject *o, HTMLPainter *painter, int offset);
+	int (*get_left_edge_offset) (HTMLObject *o, HTMLPainter *painter, int offset);
 
 	gboolean (*backspace)       (HTMLObject *self, HTMLCursor *cursor, HTMLEngine *engine);
 };
@@ -399,11 +401,11 @@ void            html_object_calc_abs_position     (HTMLObject            *o,
 						   gint                  *x_return,
 						   gint                  *y_return);
 void            html_object_calc_abs_position_in_frame (HTMLObject       *o,
-							gint              *x_return,
-							gint              *y_return);
+							int              *x_return,
+							int              *y_return);
 gboolean        html_object_intersect             (HTMLObject            *o,
-						   GdkRectangle          *intersection,
-						   gint                   x,
+					           GdkRectangle          *intersection,
+					           gint                   x,
 						   gint                   y,
 						   gint                   width,
 						   gint                   height);
@@ -549,7 +551,7 @@ void      html_object_set_data               (HTMLObject          *object,
 					      const gchar         *value);
 void      html_object_set_data_full          (HTMLObject          *object,
 					      const gchar         *key,
-					      gconstpointer       value,
+					      const gpointer       value,
 					      GDestroyNotify       func);
 gpointer  html_object_get_data               (HTMLObject          *object,
 					      const gchar         *key);
@@ -564,7 +566,7 @@ void      html_object_set_data_nocp          (HTMLObject          *object,
 					      const gchar         *value);
 void      html_object_set_data_full_nocp     (HTMLObject          *object,
 					      const gchar         *key,
-					      gconstpointer       value,
+					      const gpointer       value,
 					      GDestroyNotify       func);
 gpointer  html_object_get_data_nocp          (HTMLObject          *object,
 					      const gchar         *key);
@@ -627,16 +629,16 @@ HTMLObject *html_object_next_cursor_leaf    (HTMLObject *o,
 HTMLObject *html_object_prev_cursor_leaf    (HTMLObject *o,
 					     HTMLEngine *e);
 
-gint  html_object_get_right_edge_offset  (HTMLObject *o,
+int  html_object_get_right_edge_offset  (HTMLObject *o,
 					 HTMLPainter *painter,
-					 gint offset);
-gint  html_object_get_left_edge_offset   (HTMLObject *o,
+					 int offset);
+int  html_object_get_left_edge_offset   (HTMLObject *o,
 					 HTMLPainter *painter,
-					 gint offset);
+					 int offset);
 
-const gchar *html_object_get_id  (HTMLObject *o);
+const char *html_object_get_id  (HTMLObject *o);
 void        html_object_set_id  (HTMLObject *o,
-				 const gchar *id);
+				 const char *id);
 
 HTMLDirection html_object_get_direction (HTMLObject *o);
 HTMLClueFlow * html_object_get_flow (HTMLObject *o);
